==> owncloud-10.0.7.tgz: owncloud/apps/files_external/l10n/sl.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Pridobivanje žetonov zahteve je spodletelo. Preverite, ali sta ključ in skrivno geslo programa navedena pravilno.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Pridobivanje žetonov za dostop je spodletelo. Preverite, da sta ključ in skrivno geslo navedena pravilno.",
    "Please provide a valid app key and secret." : "Vpisati je treba veljaven ključ programa in kodo.",
    "Step 1 failed. Exception: %s" : "1. korak je spodletel. Izjemna napaka: %s",
    "Step 2 failed. Exception: %s" : "2. korak je spodletel. Izjemna napaka: %s",
    "External storage" : "Zunanja shramba",
    "Dropbox App Configuration" : "Nastavitve programa Dropbox",
    "Google Drive App Configuration" : "Nastavitve programa Google Drive",
    "Personal" : "Osebno",
    "System" : "Sistem",
    "Grant access" : "Odobri dostop",
    "Error configuring OAuth1" : "Napaka nastavljanja OAuth1",
    "Error configuring OAuth2" : "Napaka nastavljanja OAuth2",
    "Generate keys" : "Ustvari ključe",
    "Error generating key pair" : "Prišlo je do napake med ustvarjanjem para ključev",
    "All users. Type to select user or group." : "Vsi uporabniki. Skupino ali uporabnika je mogoče tudi izbrati.",
    "(group)" : "(skupina)",
    "Compatibility with Mac NFD encoding (slow)" : "Skladnost s kodiranjem Mac NFD (počasneje)",
    "Admin defined" : "Skrbnik je določen",
    "Saved" : "Shranjeno",
    "Disable external storage" : "Onemogoči zunanjo shrambo",
    "Empty response from the server" : "S strežnika je prejet odziv brez vsebine.",
    "Couldn't access. Please logout and login to activate this mount point" : "Dostop ni mogoč. Za priklop točke se odjavite in ponovno prijavite.",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Ni mogoče pridobiti podrobnosti s strežnika ownCloud:{koda} {vrsta}",
    "Couldn't get the list of external mount points: {type}" : "Ni mogoče pridobiti seznama zunanjih priklopnih točk: {type}",
    "There was an error with message: " : "Prišlo je do napake s sporočilom:",
    "External mount error" : "Notranja napaka priklopa",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Ni mogoče pridobiti seznama priklopnih točk omrežnega pogona: ni odziva s strežnika",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Nekatere izmed nastavljenih zunanjih priklopnih točk niso povezane. Več podrobnosti je na voljo s klikom na rdeče vrstice.",
    "Please enter the credentials for the {mount} mount" : "Vpišite poverila za priklopno točko {mount}",
    "Username" : "Uporabniško ime",
    "Password" : "Geslo",
    "Credentials saved" : "Poverila so shranjena",
    "Credentials saving failed" : "Shranjevanje poveril je spodletelo",
    "Credentials required" : "Zahtevana so poverila",
    "Save" : "Shrani",
    "Storage with id \"%i\" not found" : "Shrambe z ID \"%i\" ni mogoče najti.",
    "Invalid backend or authentication mechanism class" : "Neveljaven ozadnji program oziroma razred mehanizma overitve",
    "Invalid mount point" : "Neveljavna priklopna točka",
    "Objectstore forbidden" : "Shranjevanje predmeta je prepovedano",
    "Invalid storage backend \"%s\"" : "Neveljaven ozadnji program shrambe \"%s\"",
    "Not permitted to use backend \"%s\"" : "Uporaba ozadnjega programa \"%s\" ni dovoljena.",
    "Not permitted to use authentication mechanism \"%s\"" : "Uporaba načina overitve \"%s\" ni dovoljena.",
    "Unsatisfied backend parameters" : "Nezadovoljivi parametri ozadnjega programa",
    "Unsatisfied authentication mechanism parameters" : "Nezadovoljivi parametri mehanizma overitve",
    "Insufficient data: %s" : "Nepopolni podatki: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Shramba z ID \"%i\" ni uporabniško uredljiva.",
    "Access key" : "Ključ za dostop",
    "Secret key" : "Skriti ključ",
    "OAuth1" : "OAuth1",
    "App key" : "Programski ključ",
    "App secret" : "Skrivni programski ključ",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID odjemalca",
    "Client secret" : "Skrivni ključ odjemalca",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Ime uporabnika",
    "Identity endpoint URL" : "Naslov URL končne točke istovetnosti",
    "Rackspace" : "Rackspace",
    "API key" : "Ključ API",
    "RSA public key" : "Javni ključ RSA",
    "Public key" : "Javni ključ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Pomnilniško vedro",
    "Hostname" : "Ime gostitelja",
    "Port" : "Vrata",
    "Region" : "Območje",
    "Enable SSL" : "Omogoči SSL",
    "Enable Path Style" : "Omogoči slog poti",
    "WebDAV" : "WebDAV",
    "URL" : "Naslov URL",
    "Remote subfolder" : "Oddaljena podrejena mapa",
    "Secure https://" : "Varni način https://",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "Local" : "Krajevno",
    "Location" : "Mesto",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Gostitelj",
    "Root" : "Koren",
    "SFTP with secret key login" : "Prijava prek protokola SFTP z geslom",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Souporaba",
    "Domain" : "Domena",
    "SMB / CIFS using OC login" : "SMB / CIFS z uporabo prijave OC",
    "Username as share" : "Uporabniško ime za souporabo",
    "OpenStack Object Storage" : "Shramba predmeta OpenStack",
    "Service name" : "Ime storitve",
    "Request timeout (seconds)" : "Zahtevan časovni zamik (sekunde)",
    "<b>Note:</b> " : "<b>Opomba:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Opomba:</b> Podpora za naslove cURL v PHP ni omogočena, ali pa ni ustrezno nameščenih programov. Priklapljanje %s ni mogoče. Za pomoč pri namestitvi se obrnite na sistemskega skrbnika.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Opomba:</b> Program \"%s\" ni nameščen. Priklapljanje %s ni mogoče. Za pomoč pri namestitvi se obrnite na sistemskega skrbnika.",
    "No external storage configured" : "Ni določene zunanje shrambe",
    "You can add external storages in the storage settings" : "Zunanjo shrambo je mogoče dodati med nastavitvami.",
    "Name" : "Ime",
    "Storage type" : "Vrsta shrambe",
    "Scope" : "Obseg",
    "Enable encryption" : "Omogoči šifriranje",
    "Enable previews" : "Omogoči predogled",
    "Enable sharing" : "Omogoči souporabo",
    "Check for changes" : "Preveri za spremembe",
    "Never" : "Nikoli",
    "Once every direct access" : "Enkrat ob neposrednem dostopu",
    "External Storage" : "Zunanja podatkovna shramba",
    "Enable external storage" : "Omogoči zunanjo shrambo",
    "External storage has been disabled by the administrator" : "Zunanja shramba je skrbniško onemogočena.",
    "Folder name" : "Ime mape",
    "Authentication" : "Overitev",
    "Configuration" : "Nastavitve",
    "Available for" : "Na voljo za",
    "Add storage" : "Dodaj shrambo",
    "Advanced settings" : "Napredne nastavitve",
    "Delete" : "Izbriši",
    "Allow users to mount external storage" : "Dovoli uporabnikom priklapljanje zunanje shrambe",
    "Allow users to mount the following external storage" : "Dovoli uporabnikom priklapljanje navedenih zunanjih shramb."
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");

==> owncloud-10.0.10.tgz: owncloud/apps/files_external/l10n/sl.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your app key and secret are correct." : "Pridobivanje žetonov zahteve je spodletelo. Preverite, ali sta ključ in skrivno geslo programa navedena pravilno.",
    "Fetching access tokens failed. Verify that your app key and secret are correct." : "Pridobivanje žetonov za dostop je spodletelo. Preverite, da sta ključ in skrivno geslo navedena pravilno.",
    "Please provide a valid app key and secret." : "Vpisati je treba veljaven ključ programa in kodo.",
    "Step 1 failed. Exception: %s" : "1. korak je spodletel. Izjemna napaka: %s",
    "Step 2 failed. Exception: %s" : "2. korak je spodletel. Izjemna napaka: %s",
    "External storage" : "Zunanja shramba",
    "Dropbox App Configuration" : "Nastavitve programa Dropbox",
    "Google Drive App Configuration" : "Nastavitve programa Google Drive",
    "Personal" : "Osebno",
    "System" : "Sistem",
    "Grant access" : "Odobri dostop",
    "Error configuring OAuth1" : "Napaka nastavljanja OAuth1",
    "Error configuring OAuth2" : "Napaka nastavljanja OAuth2",
    "Generate keys" : "Ustvari ključe",
    "Error generating key pair" : "Prišlo je do napake med ustvarjanjem para ključev",
    "All users. Type to select user or group." : "Vsi uporabniki. Skupino ali uporabnika je mogoče tudi izbrati.",
    "(group)" : "(skupina)",
    "Compatibility with Mac NFD encoding (slow)" : "Skladnost s kodiranjem Mac NFD (počasneje)",
    "Admin defined" : "Skrbnik je določen",
    "Saved" : "Shranjeno",
    "Disable external storage" : "Onemogoči zunanjo shrambo",
    "Empty response from the server" : "S strežnika je prejet odziv brez vsebine.",
    "Couldn't access. Please logout and login to activate this mount point" : "Dostop ni mogoč. Za priklop točke se odjavite in ponovno prijavite.",
    "Couldn't get the information from the ownCloud server: {code} {type}" : "Ni mogoče pridobiti podrobnosti s strežnika ownCloud:{koda} {vrsta}",
    "Couldn't get the list of external mount points: {type}" : "Ni mogoče pridobiti seznama zunanjih priklopnih točk: {type}",
    "There was an error with message: " : "Prišlo je do napake s sporočilom:",
    "External mount error" : "Notranja napaka priklopa",
    "Couldn't get the list of Windows network drive mount points: empty response from the server" : "Ni mogoče pridobiti seznama priklopnih točk omrežnega pogona: ni odziva s strežnika",
    "Some of the configured external mount points are not connected. Please click on the red row(s) for more information" : "Nekatere izmed nastavljenih zunanjih priklopnih točk niso povezane. Več podrobnosti je na voljo s klikom na rdeče vrstice.",
    "Please enter the credentials for the {mount} mount" : "Vpišite poverila za priklopno točko {mount}",
    "Username" : "Uporabniško ime",
    "Password" : "Geslo",
    "Credentials saved" : "Poverila so shranjena",
    "Credentials saving failed" : "Shranjevanje poveril je spodletelo",
    "Credentials required" : "Zahtevana so poverila",
    "Save" : "Shrani",
    "Storage with id \"%i\" not found" : "Shrambe z ID \"%i\" ni mogoče najti.",
    "Invalid backend or authentication mechanism class" : "Neveljaven ozadnji program oziroma razred mehanizma overitve",
    "Invalid mount point" : "Neveljavna priklopna točka",
    "Objectstore forbidden" : "Shranjevanje predmeta je prepovedano",
    "Invalid storage backend \"%s\"" : "Neveljaven ozadnji program shrambe \"%s\"",
    "Not permitted to use backend \"%s\"" : "Uporaba ozadnjega programa \"%s\" ni dovoljena.",
    "Not permitted to use authentication mechanism \"%s\"" : "Uporaba načina overitve \"%s\" ni dovoljena.",
    "Unsatisfied backend parameters" : "Nezadovoljivi parametri ozadnjega programa",
    "Unsatisfied authentication mechanism parameters" : "Nezadovoljivi parametri mehanizma overitve",
    "Insufficient data: %s" : "Nepopolni podatki: %s",
    "%s" : "%s",
    "Storage with id \"%i\" is not user editable" : "Shramba z ID \"%i\" ni uporabniško uredljiva.",
    "Access key" : "Ključ za dostop",
    "Secret key" : "Skriti ključ",
    "OAuth1" : "OAuth1",
    "App key" : "Programski ključ",
    "App secret" : "Skrivni programski ključ",
    "OAuth2" : "OAuth2",
    "Client ID" : "ID odjemalca",
    "Client secret" : "Skrivni ključ odjemalca",
    "OpenStack" : "OpenStack",
    "Tenant name" : "Ime uporabnika",
    "Identity endpoint URL" : "Naslov URL končne točke istovetnosti",
    "Rackspace" : "Rackspace",
    "API key" : "Ključ API",
    "RSA public key" : "Javni ključ RSA",
    "Public key" : "Javni ključ",
    "Amazon S3" : "Amazon S3",
    "Bucket" : "Pomnilniško vedro",
    "Hostname" : "Ime gostitelja",
    "Port" : "Vrata",
    "Region" : "Območje",
    "Enable SSL" : "Omogoči SSL",
    "Enable Path Style" : "Omogoči slog poti",
    "WebDAV" : "WebDAV",
    "URL" : "Naslov URL",
    "Remote subfolder" : "Oddaljena podrejena mapa",
    "Secure https://" : "Varni način https://",
    "Dropbox" : "Dropbox",
    "Google Drive" : "Google Drive",
    "Local" : "Krajevno",
    "Location" : "Mesto",
    "ownCloud" : "ownCloud",
    "SFTP" : "SFTP",
    "Host" : "Gostitelj",
    "Root" : "Koren",
    "SFTP with secret key login" : "Prijava prek protokola SFTP z geslom",
    "SMB / CIFS" : "SMB / CIFS",
    "Share" : "Souporaba",
    "Domain" : "Domena",
    "SMB / CIFS using OC login" : "SMB / CIFS z uporabo prijave OC",
    "Username as share" : "Uporabniško ime za souporabo",
    "OpenStack Object Storage" : "Shramba predmeta OpenStack",
    "Service name" : "Ime storitve",
    "Request timeout (seconds)" : "Zahtevan časovni zamik (sekunde)",
    "<b>Note:</b> " : "<b>Opomba:</b> ",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Opomba:</b> Podpora za naslove cURL v PHP ni omogočena, ali pa ni ustrezno nameščenih programov. Priklapljanje %s ni mogoče. Za pomoč pri namestitvi se obrnite na sistemskega skrbnika.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Opomba:</b> Program \"%s\" ni nameščen. Priklapljanje %s ni mogoče. Za pomoč pri namestitvi se obrnite na sistemskega skrbnika.",
    "No external storage configured" : "Ni določene zunanje shrambe",
    "You can add external storages in the storage settings" : "Zunanjo shrambo je mogoče dodati med nastavitvami.",
    "Name" : "Ime",
    "Storage type" : "Vrsta shrambe",
    "Scope" : "Obseg",
    "Enable encryption" : "Omogoči šifriranje",
    "Enable previews" : "Omogoči predogled",
    "Enable sharing" : "Omogoči souporabo",
    "Check for changes" : "Preveri za spremembe",
    "Never" : "Nikoli",
    "Once every direct access" : "Enkrat ob neposrednem dostopu",
    "External Storage" : "Zunanja podatkovna shramba",
    "Enable external storage" : "Omogoči zunanjo shrambo",
    "External storage has been disabled by the administrator" : "Zunanja shramba je skrbniško onemogočena.",
    "Folder name" : "Ime mape",
    "Authentication" : "Overitev",
    "Configuration" : "Nastavitve",
    "Available for" : "Na voljo za",
    "Add storage" : "Dodaj shrambo",
    "Advanced settings" : "Napredne nastavitve",
    "Delete" : "Izbriši",
    "Allow users to mount external storage" : "Dovoli uporabnikom priklapljanje zunanje shrambe",
    "Allow users to mount the following external storage" : "Dovoli uporabnikom priklapljanje navedenih zunanjih shramb.",
    "Error getting OAuth2 URL for " : "Napaka pridobivanja naslova URL OAuth2 za"
},
"nplurals=4; plural=(n%100==1 ? 0 : n%100==2 ? 1 : n%100==3 || n%100==4 ? 2 : 3);");
